import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import Box from './Box'
import theme from './theme'

const Styles = {}

Styles.muted = (val) => {
  switch (val) {
    case 1:
    default: return `opacity: 0.85;`
    case 2: return `opacity: 0.7;`
  }
}

const getColor = ({ white }, theme) => {
  if (white) return `color: ${theme.colors.white[0]};`
  return ''
}

const getLineHeight = ({ lineHeight }) => {
  if (lineHeight) return `lineHeight: ${lineHeight};`
  return ''
}

const styles = ({
  muted,
  white,
  lineHeight,
  theme
}) => css`
  ${getColor({ white }, theme)}
  ${getLineHeight({ lineHeight }, theme)}
  ${muted ? Styles.muted(muted) : ''}
`

const Text = styled(({
  muted,
  white,
  lineHeight,
  ...props
}) => React.createElement(Box, props))`${styles}`

Text.propTypes = {
  ...Box.propTypes,
  lineHeight: PropTypes.string,
  white: PropTypes.bool
}

Text.defaultProps = {
  theme,
  is: 'p'
}

Text.displayName = 'Text'

export default Text
