import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'

const cssClearfix = css({
  '&:before, &:after': {
    display: 'table',
    clear: 'both',
    content: '""'
  }
})

const parseProps = ({ clearfix, className, ...props }) => ({
  className: clearfix ? cx(`${cssClearfix}`, className) : className,
  ...props
})

const withClearfix = (Comp) => {
  const ClearfixComp = (props) =>
    React.createElement(Comp, parseProps(props))

  ClearfixComp.propTypes = {
    ...Comp.propTypes,
    clearfix: PropTypes.bool
  }

  ClearfixComp.displayName = Comp.displayName

  return ClearfixComp
}

export {
  withClearfix
}
