import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  Triangle,
  DoubleTriangle,
  Arrow,
  Chevron,
  Close,
  ExclamationCircle
} from '../components'


const Docs = () => <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`aim\`| up/top, right, down/bottom, left | right | the direction the icon is aiming
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
`}
</Content>


export default function iconsStory (module) {
  storiesOf('Icons', module)
    .add('Triangle', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Triangle

The Triangle icon is a multi purpose directional icon. Implements \`<Box />\`.

\`\`\`
<Triangle aim='up' />
<Triangle aim='right' />
<Triangle aim='down' />
<Triangle aim='left' />
\`\`\`

`}
          </Content>
          <Triangle aim='up' />
          <Triangle aim='right' />
          <Triangle aim='down' />
          <Triangle aim='left' />
          <Docs />
        </Pane>
      </App>
    ))
    .add('Arrow', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Arrow

The Arrow icon is a multi purpose directional icon. Implements \`<Box />\`.

\`\`\`
<Arrow aim='up' />
<Arrow aim='right' />
<Arrow aim='down' />
<Arrow aim='left' />
\`\`\`

`}
          </Content>
          <Arrow aim='up' />
          <Arrow aim='right' />
          <Arrow aim='down' />
          <Arrow aim='left' />
          <Docs />
        </Pane>
      </App>
    ))
    .add('Chevron', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Chevron

The Chevron icon is a multi purpose directional icon. Implements \`<Box />\`.

\`\`\`
<Chevron aim='up' />
<Chevron aim='right' />
<Chevron aim='down' />
<Chevron aim='left' />
\`\`\`

`}
          </Content>
          <Chevron aim='up' />
          <Chevron aim='right' />
          <Chevron aim='down' />
          <Chevron aim='left' />
          <Docs />
        </Pane>
      </App>
    ))
    .add('Close', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Close

The Close icon is a base for close buttons. Implements \`<Box />\`.

\`\`\`
<Close />
\`\`\`

`}
          </Content>
          <Close />
          <Content markdown>
          {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Double Triangle', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Double Triangle

The DoubleTriangle icon is a icon for select's. Implements \`<Box />\`.

\`\`\`
<DoubleTriangle />
\`\`\`

`}
          </Content>
          <DoubleTriangle />
          <Content markdown>
          {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Exclamation Circle', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Exclamation Circle

The ExclamationCircle icon is a icon for input warnings. Implements \`<Box />\`.

\`\`\`
<ExclamationCircle />
\`\`\`

`}
          </Content>
          <ExclamationCircle />
          <Content markdown>
          {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
}
